@@ -69,7 +69,7 @@ def create_filename(title):
     return filename
 
 
-class Experiment():
+class Experiment(object):
     """ Class which starts logging and creates/runs the results and worker processes.
 
     .. code-block:: python
@@ -253,4 +253,4 @@ class Experiment():
         if self.worker.is_alive():
             self.worker.recorder_queue.put(None)
             self.worker.monitor_queue.put(None)
-            self.worker.stop()
\ No newline at end of file
+            self.worker.stop()
